@@ -33,7 +33,7 @@ var (
 	keyMatch4Re *regexp.Regexp = regexp.MustCompile(`{([^/]+)}`)
 )
 
-// validate the variadic parameter size and type as string
+// validate the variadic parameter size and type as string.
 func validateVariadicArgs(expectedLen int, args ...interface{}) error {
 	if len(args) != expectedLen {
 		return fmt.Errorf("expected %d arguments, but got %d", expectedLen, len(args))
@@ -49,7 +49,7 @@ func validateVariadicArgs(expectedLen int, args ...interface{}) error {
 	return nil
 }
 
-// validate the variadic string parameter size
+// validate the variadic string parameter size.
 func validateVariadicStringArgs(expectedLen int, args ...string) error {
 	if len(args) != expectedLen {
 		return fmt.Errorf("expected %d arguments, but got %d", expectedLen, len(args))
@@ -58,7 +58,7 @@ func validateVariadicStringArgs(expectedLen int, args ...string) error {
 }
 
 // KeyMatch determines whether key1 matches the pattern of key2 (similar to RESTful path), key2 can contain a *.
-// For example, "/foo/bar" matches "/foo/*"
+// For example, "/foo/bar" matches "/foo/*".
 func KeyMatch(key1 string, key2 string) bool {
 	i := strings.Index(key2, "*")
 	if i == -1 {
@@ -74,18 +74,18 @@ func KeyMatch(key1 string, key2 string) bool {
 // KeyMatchFunc is the wrapper for KeyMatch.
 func KeyMatchFunc(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyMatch", err)
+		return false, fmt.Errorf("%s: %w", "keyMatch", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(KeyMatch(name1, name2)), nil
+	return KeyMatch(name1, name2), nil
 }
 
 // KeyGet returns the matched part
 // For example, "/foo/bar/foo" matches "/foo/*"
-// "bar/foo" will been returned
+// "bar/foo" will been returned.
 func KeyGet(key1, key2 string) string {
 	i := strings.Index(key2, "*")
 	if i == -1 {
@@ -99,10 +99,10 @@ func KeyGet(key1, key2 string) string {
 	return ""
 }
 
-// KeyGetFunc is the wrapper for KeyGet
+// KeyGetFunc is the wrapper for KeyGet.
 func KeyGetFunc(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyGet", err)
+		return false, fmt.Errorf("%s: %w", "keyGet", err)
 	}
 
 	name1 := args[0].(string)
@@ -112,7 +112,7 @@ func KeyGetFunc(args ...interface{}) (interface{}, error) {
 }
 
 // KeyMatch2 determines whether key1 matches the pattern of key2 (similar to RESTful path), key2 can contain a *.
-// For example, "/foo/bar" matches "/foo/*", "/resource1" matches "/:resource"
+// For example, "/foo/bar" matches "/foo/*", "/resource1" matches "/:resource".
 func KeyMatch2(key1 string, key2 string) bool {
 	key2 = strings.Replace(key2, "/*", "/.*", -1)
 
@@ -125,18 +125,18 @@ func KeyMatch2(key1 string, key2 string) bool {
 // KeyMatch2Func is the wrapper for KeyMatch2.
 func KeyMatch2Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyMatch2", err)
+		return false, fmt.Errorf("%s: %w", "keyMatch2", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(KeyMatch2(name1, name2)), nil
+	return KeyMatch2(name1, name2), nil
 }
 
 // KeyGet2 returns value matched pattern
 // For example, "/resource1" matches "/:resource"
-// if the pathVar == "resource", then "resource1" will be returned
+// if the pathVar == "resource", then "resource1" will be returned.
 func KeyGet2(key1, key2 string, pathVar string) string {
 	key2 = strings.Replace(key2, "/*", "/.*", -1)
 
@@ -157,10 +157,10 @@ func KeyGet2(key1, key2 string, pathVar string) string {
 	return ""
 }
 
-// KeyGet2Func is the wrapper for KeyGet2
+// KeyGet2Func is the wrapper for KeyGet2.
 func KeyGet2Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(3, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyGet2", err)
+		return false, fmt.Errorf("%s: %w", "keyGet2", err)
 	}
 
 	name1 := args[0].(string)
@@ -171,7 +171,7 @@ func KeyGet2Func(args ...interface{}) (interface{}, error) {
 }
 
 // KeyMatch3 determines whether key1 matches the pattern of key2 (similar to RESTful path), key2 can contain a *.
-// For example, "/foo/bar" matches "/foo/*", "/resource1" matches "/{resource}"
+// For example, "/foo/bar" matches "/foo/*", "/resource1" matches "/{resource}".
 func KeyMatch3(key1 string, key2 string) bool {
 	key2 = strings.Replace(key2, "/*", "/.*", -1)
 
@@ -184,18 +184,18 @@ func KeyMatch3(key1 string, key2 string) bool {
 // KeyMatch3Func is the wrapper for KeyMatch3.
 func KeyMatch3Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyMatch3", err)
+		return false, fmt.Errorf("%s: %w", "keyMatch3", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(KeyMatch3(name1, name2)), nil
+	return KeyMatch3(name1, name2), nil
 }
 
 // KeyGet3 returns value matched pattern
 // For example, "project/proj_project1_admin/" matches "project/proj_{project}_admin/"
-// if the pathVar == "project", then "project1" will be returned
+// if the pathVar == "project", then "project1" will be returned.
 func KeyGet3(key1, key2 string, pathVar string) string {
 	key2 = strings.Replace(key2, "/*", "/.*", -1)
 
@@ -216,10 +216,10 @@ func KeyGet3(key1, key2 string, pathVar string) string {
 	return ""
 }
 
-// KeyGet3Func is the wrapper for KeyGet3
+// KeyGet3Func is the wrapper for KeyGet3.
 func KeyGet3Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(3, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyGet3", err)
+		return false, fmt.Errorf("%s: %w", "keyGet3", err)
 	}
 
 	name1 := args[0].(string)
@@ -273,20 +273,20 @@ func KeyMatch4(key1 string, key2 string) bool {
 // KeyMatch4Func is the wrapper for KeyMatch4.
 func KeyMatch4Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyMatch4", err)
+		return false, fmt.Errorf("%s: %w", "keyMatch4", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(KeyMatch4(name1, name2)), nil
+	return KeyMatch4(name1, name2), nil
 }
 
 // KeyMatch5 determines whether key1 matches the pattern of key2 (similar to RESTful path), key2 can contain a *
 // For example,
 // - "/foo/bar?status=1&type=2" matches "/foo/bar"
 // - "/parent/child1" and "/parent/child1" matches "/parent/*"
-// - "/parent/child1?status=1" matches "/parent/*"
+// - "/parent/child1?status=1" matches "/parent/*".
 func KeyMatch5(key1 string, key2 string) bool {
 	i := strings.Index(key1, "?")
 
@@ -305,13 +305,13 @@ func KeyMatch5(key1 string, key2 string) bool {
 // KeyMatch5Func is the wrapper for KeyMatch5.
 func KeyMatch5Func(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "keyMatch5", err)
+		return false, fmt.Errorf("%s: %w", "keyMatch5", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(KeyMatch5(name1, name2)), nil
+	return KeyMatch5(name1, name2), nil
 }
 
 // RegexMatch determines whether key1 matches the pattern of key2 in regular expression.
@@ -326,17 +326,17 @@ func RegexMatch(key1 string, key2 string) bool {
 // RegexMatchFunc is the wrapper for RegexMatch.
 func RegexMatchFunc(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "regexMatch", err)
+		return false, fmt.Errorf("%s: %w", "regexMatch", err)
 	}
 
 	name1 := args[0].(string)
 	name2 := args[1].(string)
 
-	return bool(RegexMatch(name1, name2)), nil
+	return RegexMatch(name1, name2), nil
 }
 
 // IPMatch determines whether IP address ip1 matches the pattern of IP address ip2, ip2 can be an IP address or a CIDR pattern.
-// For example, "192.168.2.123" matches "192.168.2.0/24"
+// For example, "192.168.2.123" matches "192.168.2.0/24".
 func IPMatch(ip1 string, ip2 string) bool {
 	objIP1 := net.ParseIP(ip1)
 	if objIP1 == nil {
@@ -359,16 +359,16 @@ func IPMatch(ip1 string, ip2 string) bool {
 // IPMatchFunc is the wrapper for IPMatch.
 func IPMatchFunc(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "ipMatch", err)
+		return false, fmt.Errorf("%s: %w", "ipMatch", err)
 	}
 
 	ip1 := args[0].(string)
 	ip2 := args[1].(string)
 
-	return bool(IPMatch(ip1, ip2)), nil
+	return IPMatch(ip1, ip2), nil
 }
 
-// GlobMatch determines whether key1 matches the pattern of key2 using glob pattern
+// GlobMatch determines whether key1 matches the pattern of key2 using glob pattern.
 func GlobMatch(key1 string, key2 string) (bool, error) {
 	return path.Match(key2, key1)
 }
@@ -376,7 +376,7 @@ func GlobMatch(key1 string, key2 string) (bool, error) {
 // GlobMatchFunc is the wrapper for GlobMatch.
 func GlobMatchFunc(args ...interface{}) (interface{}, error) {
 	if err := validateVariadicArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "globMatch", err)
+		return false, fmt.Errorf("%s: %w", "globMatch", err)
 	}
 
 	name1 := args[0].(string)
@@ -453,13 +453,13 @@ func GenerateConditionalGFunction(crm rbac.ConditionalRoleManager) govaluate.Exp
 // TimeMatchFunc is the wrapper for TimeMatch.
 func TimeMatchFunc(args ...string) (bool, error) {
 	if err := validateVariadicStringArgs(2, args...); err != nil {
-		return false, fmt.Errorf("%s: %s", "TimeMatch", err)
+		return false, fmt.Errorf("%s: %w", "TimeMatch", err)
 	}
 	return TimeMatch(args[0], args[1])
 }
 
 // TimeMatch determines whether the current time is between startTime and endTime.
-// You can use "_" to indicate that the parameter is ignored
+// You can use "_" to indicate that the parameter is ignored.
 func TimeMatch(startTime, endTime string) (bool, error) {
 	now := time.Now()
 	if startTime != "_" {
